
## CATO-CLI - mutation.sites.updateSecondaryAwsVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateSecondaryAwsVSocket) for documentation on this operation.

### Usage for mutation.sites.updateSecondaryAwsVSocket:

`catocli mutation sites updateSecondaryAwsVSocket -h`

`catocli mutation sites updateSecondaryAwsVSocket <json>`

`catocli mutation sites updateSecondaryAwsVSocket "$(cat < updateSecondaryAwsVSocket.json)"`

`catocli mutation sites updateSecondaryAwsVSocket '{"updateSecondaryAwsVSocketInput": {"id": {"id": "ID"}, "ipAddress": {"ipAddress": "IPAddress"}, "routeTableId": {"routeTableId": "String"}, "subnet": {"subnet": "NetworkSubnet"}}}'`

#### Operation Arguments for mutation.sites.updateSecondaryAwsVSocket ####
`accountId` [ID] - (required) N/A 
`updateSecondaryAwsVSocketInput` [UpdateSecondaryAwsVSocketInput] - (required) N/A 
